@@ -7,7 +7,7 @@
 #
 
 package CPANPLUS::Dist::Fedora;
-$CPANPLUS::Dist::Fedora::VERSION = '0.4.3';
+$CPANPLUS::Dist::Fedora::VERSION = '0.4.4';
 use strict;
 use warnings;
 
@@ -43,9 +43,8 @@ Name:       [% status.rpmname %]
 Version:    [% status.distvers %]
 Release:    [% status.rpmvers %]%{?dist}
 License:    [% status.license %]
-Group:      Development/Libraries
 Summary:    [% status.summary %]
-Source:     http://search.cpan.org/CPAN/[% module.path %]/[% status.distname %]-%{version}.[% module.package_extension %]
+Source:     https://cpan.metacpan.org/[% module.path %]/[% status.distname %]-%{version}.[% module.package_extension %]
 Url:        http://metacpan.org/release/[% status.distname %]
 Requires:  perl(:MODULE_COMPAT_%(eval "`[% perl_exe %] -V:version`"; echo $version))
 [% IF status.is_noarch %]BuildArch:  noarch[% END %]
@@ -54,7 +53,7 @@ Requires:  perl(:MODULE_COMPAT_%(eval "`[% perl_exe %] -V:version`"; echo $versi
 [% END -%]
 BuildRequires: coreutils
 BuildRequires: make
-BuildRequires: perl(ExtUtils::MakeMaker)
+BuildRequires: perl(ExtUtils::MakeMaker) >= 6.76
 BuildRequires: perl-devel
 BuildRequires: perl-generators
 BuildRequires: perl-interpreter
@@ -84,9 +83,11 @@ BuildRequires: perl-interpreter
 find %{buildroot} -type f \( -name .packlist -o -name perllocal.pod \) -exec rm -f {} ';'
 [%- END -%]
 [% IF (!status.is_noarch) -%]
-find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
+find %{buildroot} -type f -name '*.bs' -empty -delete
 [% END -%]
+[% IF 0 -%]
 find %{buildroot} -depth -type d -exec rmdir {} 2>/dev/null ';'
+[% END %]
 
 %{_fixperms} %{buildroot}/*
 
@@ -234,6 +235,8 @@ sub _calc_spec_text
         \$spec_text,
     );
 
+    $spec_text =~ s/\A\s+//ms;
+
     my $ret = +{ text => $spec_text, };
     if ($CPANPLUS::Dist::Fedora::_testme)
     {
@@ -708,7 +711,7 @@ CPANPLUS::Dist::Fedora - a cpanplus backend to build Fedora/RedHat rpms
 
 =head1 VERSION
 
-version 0.4.3
+version 0.4.4
 
 =head1 SYNOPSIS
 
